@@ -9,6 +9,7 @@ import sys
 import getpass
 import socket
 from jabbapylib.process import process
+from jabbapylib.filesystem import ini
 from jabbapylib import config as cfg
 
 
@@ -44,6 +45,15 @@ def get_screen_resolution():
     result = tuple([int(x) for x in result.split()[0].split('x')])
     return result
 
+def get_firefox_profile_folder():
+    """
+    Location of Firefox's default profile folder. Typically, it looks like this:
+    $HOME/.mozilla/firefox/xxxxxxxx.default .
+    """
+    ini_file = '{home}/.mozilla/firefox/profiles.ini'.format(home=get_home_dir())
+    folder = ini.read_ini('Profile0', ini_file)['path']
+    return '{home}/.mozilla/firefox/{folder}'.format(home=get_home_dir(), folder=folder)
+
 #############################################################################
 
 if __name__ == "__main__":
@@ -52,3 +62,4 @@ if __name__ == "__main__":
     print get_username()
     print is_linux()
     print get_screen_resolution()
+    print get_firefox_profile_folder()
\ No newline at end of file
